@@ -337,7 +337,11 @@ class ProviderConfig(object):
             "state": redirect_to,
         })
         if self._mode == "openid_connect":
-            query["scope"] = "openid"
+            if settings.VERSION == 'v2.0':
+                query["scope"] = f"openid api://{settings.RELYING_PARTY_ID}/.default"
+                query.pop("resource")
+            else:
+                query["scope"] = "openid"
             if (disable_sso is None and settings.DISABLE_SSO) or disable_sso is True:
                 query["prompt"] = "login"
             if force_mfa:
